import './index.css';


var dessinEnCours = 1;
var dessinMax = 1;
var canvasMouse, contextMouse;

var started = false;
var x, y;
var donnees = [];


var options = document.getElementById('options');
var menu = document.getElementById('menu');
var images = document.getElementById('images');


document.addEventListener("DOMContentLoaded", function() {
    const ws = new WebSocket("ws://" + window.location.host + "/socket");
    initMouse();

    //change la taille et la couleur
    options.onclick = function(c) {
        var option = c.target.className.substring(1);
        if(c.target.className.charAt(0) === 't'){
            contextMouse.lineWidth = option;
        }
        else if(c.target.className.charAt(0) === 'c'){
            contextMouse.strokeStyle = option;
        }
    }

    //click sur les boutons
    menu.onclick = function(c) {
        if(c.target.className === "newPaint"){//nouveau dessin
            if (dessinMax === 4) {
                alert("Erreur, limite de dessin atteinte !") //limite de 4 dessins
            } else {
                ws.send("3," + dessinMax + "," + dessinEnCours);
                clear();
            }
        }
        else if(c.target.className === "save"){//sauvegarde
            ws.send("4," + dessinEnCours);
        }
        else if(c.target.className === "erase"){//efface
            clear();
        }
    }

    //initialise la souris
    function initMouse() {

        // Get the drawing canvas
        canvasMouse = document.getElementById('canvas3');
        contextMouse = canvasMouse.getContext('2d');

        contextMouse.strokeStyle = '#000';
        contextMouse.lineWidth = 1;

        // Add some event listeners so we can figure out what's happening
        // and run a few functions when they are executed.
        canvasMouse.addEventListener('mousemove', mousemovement, false);
        canvasMouse.addEventListener('mousedown', mouseclick, false);
        canvasMouse.addEventListener('mouseup', mouseunclick, false);
    }

    function mouseclick() {
        contextMouse.beginPath();
        contextMouse.moveTo(x, y);
        started = true;

        donnees.push(contextMouse.lineWidth);
        donnees.push(contextMouse.strokeStyle);
        donnees.push(x);
        donnees.push(y);
    }


    function getOffset(e) {
        var cx = 0;
        var cy = 0;

        while (e && !isNaN(e.offsetLeft) && !isNaN(e.offsetTop)) {
            cx += e.offsetLeft - e.scrollLeft;
            cy += e.offsetTop - e.scrollTop;
            e = e.offsetParent;
        }
        return {top: cy, left: cx};
    }

    //recupere le mouvement de la souris
    function mousemovement(e) {
        if (e.offsetX || e.offsetY) {
            x = e.pageX - getOffset(document.getElementById('canvas3')).left - window.pageXOffset;
            y = e.pageY - getOffset(document.getElementById('canvas3')).top - window.pageYOffset;
        }
        else if (e.layerX || e.layerY) {
            x = (e.clientX + document.body.scrollLeft + document.documentElement.scrollLeft)
                - getOffset(document.getElementById('canvas3')).left - window.pageXOffset;
            y = (e.clientY + document.body.scrollTop + document.documentElement.scrollTop)
                - getOffset(document.getElementById('canvas3')).top;
        }

        // si on dessine on affiche le dessin
        if (started) {
            contextMouse.lineTo(x, y);
            contextMouse.stroke();

            donnees.push(x);
            donnees.push(y);
        }
    }

    //on envoie le dessin quand l'user arrete de dessiner
    function mouseunclick() {
        if (started) {
            started = false;
        }
        sendInfo();
    }

    //recupere une autre image
    images.onclick = function(c){
        ws.send("5," + c.target.className);
    }

    function clear() {
        ws.send("2");
    }

    function sendInfo() {
        ws.send("1," + donnees);
        donnees = [];
    }

    ws.onopen = (event) => {
        console.log("We are connected.");
    };

    ws.onmessage = (event) => {
        var width = contextMouse.lineWidth;
        var color = contextMouse.strokeStyle;

        var result = event.data.split(",");

        if (result[0] === "1") {//on dessine
            contextMouse.beginPath();

            contextMouse.lineWidth = result[1];
            contextMouse.strokeStyle = result[2];

            contextMouse.moveTo(result[3], result[4]);

            for (var i = 5; i < result.length; i = i + 2) {
                contextMouse.lineTo(result[i], result[i + 1]);
                contextMouse.stroke();
            }

            started = false;
            contextMouse.lineWidth = width;
            contextMouse.strokeStyle = color;

        }
        else if (result[0] === "2") {//on efface
            contextMouse.clearRect(0, 0, 690, 500);
        }
        else if (result[0] === "3") {//nouveau dessin
            if (document.getElementById('image' + result[1]).src !== "") {
                dessinMax = parseInt(result[1], 10) + 1;
                dessinEnCours = dessinMax;
            }
        }
        else if (result[0] === "4") {//save
            var dataURL = document.getElementById('canvas3').toDataURL();
            document.getElementById('image' + result[1]).src = dataURL;
            document.getElementById('image' + result[1]).style.backgroundColor = "#fff";
        }
        else if (result[0] === "5") {//charger une image
            contextMouse.clearRect(0, 0, 690, 500);
            var ctx = document.getElementById('canvas3').getContext('2d');
            ctx.drawImage(document.getElementById('image' + result[1]), 0, 0);
            dessinEnCours = result[1];
        }
    };
});